@@ -85,6 +85,7 @@ sub _CC_ {
         print STDERR $stderr;
         print STDOUT $stdout;
     } else {
+        no warnings;
         print LOG $stdout;
     }
 }
@@ -96,6 +97,7 @@ sub _LD_ {
         print STDERR $stderr;
         print STDOUT $stdout;
     } else {
+        no warnings;
         print LOG $stdout;
     }
 }
@@ -234,6 +236,7 @@ sub ACTION_create_objects {
     mkpath "_build/objects" unless -d "_build/objects";
 
     my $cflags = $self->notes('cflags');
+    $cflags .= " -DMISSES_WCSDUP" unless $self->notes('have_wcsdup');
     $cflags .= " -g -Wall -Werror" if $pedantic;
 
     for my $object (keys %o_deps) {
